@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2025 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -30,13 +30,15 @@ class OGRSpatialReference;
 
 #include <cassert>
 #include <iostream>
+#include <memory>
 #include <utility>
-#include <vector>
 
 extern SRS srs;
 extern bool debug;
 
-static std::unique_ptr<OGRPolygon> create_rectangular_polygon(double x1, double y1, double x2, double y2, double expand) {
+namespace {
+
+std::unique_ptr<OGRPolygon> create_rectangular_polygon(double x1, double y1, double x2, double y2, double expand) {
     OGREnvelope e;
 
     e.MinX = x1 - expand;
@@ -61,7 +63,7 @@ static std::unique_ptr<OGRPolygon> create_rectangular_polygon(double x1, double
     return polygon;
 }
 
-static bool add_segment_to_line(OGRLineString* line, OGRPoint* point1, OGRPoint* point2) {
+bool add_segment_to_line(OGRLineString* line, OGRPoint* point1, OGRPoint* point2) {
     // segments along southern edge of the map are not added to line output
     if (point1->getY() < srs.min_y() && point2->getY() < srs.min_y()) {
         if (debug) {
@@ -86,6 +88,8 @@ static bool add_segment_to_line(OGRLineString* line, OGRPoint* point1, OGRPoint*
     return true;
 }
 
+} // anonymous namespace
+
 unsigned int CoastlinePolygons::fix_direction() {
     unsigned int warnings = 0;
 
@@ -93,15 +97,11 @@ unsigned int CoastlinePolygons::fix_direction() {
         OGRLinearRing* er = polygon->getExteriorRing();
         assert(er);
         if (!er->isClockwise()) {
-            er->reverseWindingOrder();
-            // Workaround for bug in OGR: reverseWindingOrder sets dimensions to 3
-            er->setCoordinateDimension(2);
+            er->reversePoints();
             for (int i = 0; i < polygon->getNumInteriorRings(); ++i) {
                 OGRLinearRing* ir = polygon->getInteriorRing(i);
                 assert(ir);
-                ir->reverseWindingOrder();
-                // Workaround for bug in OGR: reverseWindingOrder sets dimensions to 3
-                ir->setCoordinateDimension(2);
+                ir->reversePoints();
             }
             m_output.add_error_line(make_unique_ptr_clone<OGRLineString>(er), "direction");
             warnings++;
@@ -254,7 +254,11 @@ void CoastlinePolygons::output_land_polygons(bool make_copy) {
     }
 }
 
+#if (GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(3,7,0))
+void CoastlinePolygons::add_line_to_output(std::unique_ptr<OGRLineString> line, const OGRSpatialReference* srs) const {
+#else
 void CoastlinePolygons::add_line_to_output(std::unique_ptr<OGRLineString> line, OGRSpatialReference* srs) const {
+#endif
     line->setCoordinateDimension(2);
     line->assignSpatialReference(srs);
     m_output.add_line(std::move(line));
