@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2025 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -27,8 +27,11 @@
 #include <ogr_geometry.h>
 
 #include <cassert>
+#include <cstdlib>
 #include <iostream>
+#include <memory>
 #include <utility>
+#include <vector>
 
 void CoastlineRing::setup_locations(locmap_type& locmap) {
     for (auto& wn : m_way_node_list) {
@@ -156,8 +159,8 @@ std::unique_ptr<OGRPoint> CoastlineRing::ogr_last_point() const {
 double CoastlineRing::distance_to_start_location(osmium::Location pos) const {
     assert(!m_way_node_list.empty());
     const osmium::Location p = m_way_node_list.front().location();
-    return (pos.lon() - p.lon()) * (pos.lon() - p.lon()) +
-           (pos.lat() - p.lat()) * (pos.lat() - p.lat());
+    return ((pos.lon() - p.lon()) * (pos.lon() - p.lon())) +
+           ((pos.lat() - p.lat()) * (pos.lat() - p.lat()));
 }
 
 void CoastlineRing::add_segments_to_vector(std::vector<osmium::UndirectedSegment>& segments) const {
