@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2025 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -26,8 +26,12 @@
 
 #include <ogr_geometry.h>
 
+#include <algorithm>
+#include <cassert>
 #include <iostream>
 #include <memory>
+#include <utility>
+#include <vector>
 
 #ifdef _MSC_VER
 #include <io.h>
@@ -129,6 +133,8 @@ unsigned int CoastlineRingCollection::check_locations(bool output_missing) {
     return missing_locations;
 }
 
+namespace {
+
 bool is_valid_polygon(const OGRGeometry* geometry) {
     if (geometry && geometry->getGeometryType() == wkbPolygon && !geometry->IsEmpty()) {
         const auto *const polygon = static_cast<const OGRPolygon*>(geometry);
@@ -137,6 +143,8 @@ bool is_valid_polygon(const OGRGeometry* geometry) {
     return false;
 }
 
+} // anonymous namespace
+
 std::vector<OGRGeometry*> CoastlineRingCollection::add_polygons_to_vector() {
     std::vector<OGRGeometry*> vector;
     vector.reserve(m_list.size());
@@ -189,6 +197,8 @@ unsigned int CoastlineRingCollection::output_rings(OutputDatabase& output) {
     return warnings;
 }
 
+namespace {
+
 osmium::Location intersection(const osmium::Segment& s1, const osmium::Segment&s2) {
     if (s1.first()  == s2.first()  ||
         s1.first()  == s2.second() ||
@@ -210,8 +220,8 @@ osmium::Location intersection(const osmium::Segment& s1, const osmium::Segment&s
         if ((denom > 0 && nume_a >= 0 && nume_a <= denom && nume_b >= 0 && nume_b <= denom) ||
             (denom < 0 && nume_a <= 0 && nume_a >= denom && nume_b <= 0 && nume_b >= denom)) {
             const double ua = nume_a / denom;
-            const double ix = s1.first().lon() + ua*(s1.second().lon() - s1.first().lon());
-            const double iy = s1.first().lat() + ua*(s1.second().lat() - s1.first().lat());
+            const double ix = s1.first().lon() + (ua * (s1.second().lon() - s1.first().lon()));
+            const double iy = s1.first().lat() + (ua * (s1.second().lat() - s1.first().lat()));
             return {ix, iy};
         }
     }
@@ -242,6 +252,8 @@ std::unique_ptr<OGRLineString> create_ogr_linestring(const osmium::Segment& segm
     return line;
 }
 
+} // anonymous namespace
+
 /**
  * Checks if there are intersections between any coastline segments.
  * Returns the number of intersections and overlaps.
