@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2025 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -35,7 +35,9 @@
 
 #include <osmium/io/pbf.hpp>
 
-static void print_help() {
+namespace {
+
+void print_help() {
     std::cout << "Usage: osmcoastline [OPTIONS] OSMFILE\n"
               << "\nOptions:\n"
               << "  -h, --help                 - This help message\n"
@@ -44,6 +46,7 @@ static void print_help() {
               << "  -b, --bbox-overlap=OVERLAP - Set overlap when splitting polygons\n"
               << "  -i, --no-index             - Do not create spatial indexes in output db\n"
               << "  -d, --debug                - Enable debugging output\n"
+              << "  -e, --exit-ignore-warnings - Exit with code 0 even if there are warnings\n"
               << "  -f, --overwrite            - Overwrite output file if it already exists\n"
               << "  -g, --gdal-driver=DRIVER   - GDAL driver (SQLite or ESRI Shapefile)\n"
               << "  -l, --output-lines         - Output coastlines as lines to database file\n"
@@ -60,14 +63,14 @@ static void print_help() {
               << "\n";
 }
 
-static void print_version() {
+void print_version() {
     std::cout << "osmcoastline " << get_osmcoastline_long_version() << "\n"
               << get_libosmium_version() << '\n'
               << "Supported PBF compression types:";
     for (const auto& type : osmium::io::supported_pbf_compression_types()) {
         std::cout << " " << type;
     }
-    std::cout << "\n\nCopyright (C) 2012-2022  Jochen Topf <jochen@topf.org>\n"
+    std::cout << "\n\nCopyright (C) 2012-2025  Jochen Topf <jochen@topf.org>\n"
               << "License: GNU GENERAL PUBLIC LICENSE Version 3 <https://gnu.org/licenses/gpl.html>.\n"
               << "This is free software: you are free to change and redistribute it.\n"
               << "There is NO WARRANTY, to the extent permitted by law.\n";
@@ -78,7 +81,7 @@ static void print_version() {
  * of specifying WGS84 or the "Web Mercator" SRS. More are currently
  * not supported.
  */
-static int get_epsg(const char* text) {
+int get_epsg(const char* text) {
     if (!strcasecmp(text, "WGS84") || !std::strcmp(text, "4326")) {
         return 4326;
     }
@@ -93,12 +96,15 @@ static int get_epsg(const char* text) {
     std::exit(return_code_cmdline);
 }
 
+} // anonymous namespace
+
 int Options::parse(int argc, char* argv[]) {
     static struct option long_options[] = {
         {"bbox-overlap",    required_argument, nullptr, 'b'},
         {"close-distance",  required_argument, nullptr, 'c'},
         {"no-index",              no_argument, nullptr, 'i'},
         {"debug",                 no_argument, nullptr, 'd'},
+        {"exit-ignore-warnings",  no_argument, nullptr, 'e'},
         {"gdal-driver",     required_argument, nullptr, 'g'},
         {"help",                  no_argument, nullptr, 'h'},
         {"output-lines",          no_argument, nullptr, 'l'},
@@ -115,7 +121,7 @@ int Options::parse(int argc, char* argv[]) {
     };
 
     while (true) {
-        const int c = getopt_long(argc, argv, "b:c:idg:hlm:o:p:rfs:S:vV", long_options, nullptr);
+        const int c = getopt_long(argc, argv, "b:c:ideg:hlm:o:p:rfs:S:vV", long_options, nullptr);
         if (c == -1) {
             break;
         }
@@ -134,6 +140,9 @@ int Options::parse(int argc, char* argv[]) {
                 debug = true;
                 std::cerr << "Enabled debug option\n";
                 break;
+            case 'e':
+                exit_ignore_warnings = true;
+                break;
             case 'h':
                 print_help();
                 return return_code_ok;
