@@ -3,7 +3,7 @@
 
 /*
 
-  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2025 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -90,6 +90,9 @@ struct Options {
     /// Verbose output?
     bool verbose = false;
 
+    /// Exit program with code 0 even if there are warnings?
+    bool exit_ignore_warnings = false;
+
     /// Name of optional segment file
     std::string segmentfile;
 
