@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2025 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -34,7 +34,6 @@
 #include <osmium/osm/entity_bits.hpp>
 #include <osmium/util/memory.hpp>
 #include <osmium/util/verbose_output.hpp>
-#include <osmium/visitor.hpp>
 
 #include <ogr_core.h>
 #include <ogr_geometry.h>
@@ -43,6 +42,7 @@
 #include <cerrno>
 #include <cstdlib>
 #include <cstring>
+#include <exception>
 #include <iostream>
 #include <memory>
 #include <sstream>
@@ -64,6 +64,8 @@ SRS srs;
 // Global debug marker
 bool debug;
 
+namespace {
+
 // If there are more than this many warnings, the program exit code will indicate an error.
 const unsigned int max_warnings = 500;
 
@@ -166,6 +168,8 @@ std::unique_ptr<OutputDatabase> open_output_database(const std::string& driver,
     return nullptr;
 }
 
+} // anonymous namespace
+
 /* ================================================== */
 
 int main(int argc, char *argv[]) {
@@ -426,7 +430,7 @@ int main(int argc, char *argv[]) {
         return return_code_error;
     }
 
-    if (warnings) {
+    if (warnings && !options.exit_ignore_warnings) {
         return return_code_warning;
     }
 
