@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2025 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -41,10 +41,12 @@
 #include <algorithm>
 #include <cstdlib>
 #include <cstring>
+#include <exception>
 #include <getopt.h>
 #include <iostream>
 #include <string>
-#include <vector>
+
+namespace {
 
 void print_help() {
     std::cout << "Usage: osmcoastline_filter [OPTIONS] OSMFILE\n"
@@ -57,6 +59,8 @@ void print_help() {
               << "\n";
 }
 
+} // anonymous namespace
+
 int main(int argc, char* argv[]) {
     std::string output_filename;
     std::string output_file_format{"pbf"};
@@ -92,7 +96,7 @@ int main(int argc, char* argv[]) {
                 break;
             case 'V':
                 std::cout << "osmcoastline_filter " << get_osmcoastline_long_version() << " / " << get_libosmium_version() << '\n'
-                          << "Copyright (C) 2012-2022  Jochen Topf <jochen@topf.org>\n"
+                          << "Copyright (C) 2012-2025  Jochen Topf <jochen@topf.org>\n"
                           << "License: GNU GENERAL PUBLIC LICENSE Version 3 <https://gnu.org/licenses/gpl.html>.\n"
                           << "This is free software: you are free to change and redistribute it.\n"
                           << "There is NO WARRANTY, to the extent permitted by law.\n";
