@@ -1,6 +1,6 @@
 /*
 
-  Copyright 2012-2022 Jochen Topf <jochen@topf.org>.
+  Copyright 2012-2025 Jochen Topf <jochen@topf.org>.
 
   This file is part of OSMCoastline.
 
@@ -30,16 +30,17 @@
 #include <algorithm>
 #include <cerrno>
 #include <cstdlib>
+#include <exception>
 #include <fcntl.h>
 #include <getopt.h>
 #include <iostream>
 #include <iterator>
 #include <memory>
-#include <stdexcept>
 #include <string>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <system_error>
+#include <utility>
 #include <vector>
 
 #ifndef _MSC_VER
@@ -79,6 +80,8 @@ public:
 
 }; // class InputFile
 
+namespace {
+
 void print_help() {
 }
 
@@ -110,6 +113,8 @@ void output_ogr(const std::string& filename, const std::string& driver_name, con
     layer.commit_transaction();
 }
 
+} // anonymous namespace
+
 int main(int argc, char *argv[]) {
     bool dump = false;
     std::string format = "ESRI Shapefile";
@@ -147,7 +152,7 @@ int main(int argc, char *argv[]) {
             }
             case 'V':
                 std::cout << "osmcoastline_segments " << get_osmcoastline_long_version() << " / " << get_libosmium_version() << '\n'
-                          << "Copyright (C) 2012-2022  Jochen Topf <jochen@topf.org>\n"
+                          << "Copyright (C) 2012-2025  Jochen Topf <jochen@topf.org>\n"
                           << "License: GNU GENERAL PUBLIC LICENSE Version 3 <https://gnu.org/licenses/gpl.html>.\n"
                           << "This is free software: you are free to change and redistribute it.\n"
                           << "There is NO WARRANTY, to the extent permitted by law.\n";
