@@ -5,13 +5,14 @@
 #
 #-----------------------------------------------------------------------------
 
-. $1/test/init.sh
+# shellcheck source=test/init.sh
+. "$1/test/init.sh"
 
 set -x
 
 #-----------------------------------------------------------------------------
 
-cat <<'OSM' >$INPUT
+cat <<'OSM' >"$INPUT"
 n100 v1 x1.00 y1.00
 n101 v1 x1.00 y1.01
 n102 v1 x1.01 y1.01
@@ -23,24 +24,26 @@ OSM
 
 #-----------------------------------------------------------------------------
 
-$OSMC --verbose --overwrite --output-database=$DB $INPUT >$LOG 2>&1
+"$OSMC" --verbose --overwrite --srs="$SRID" --output-database="$DB" "$INPUT" >"$LOG" 2>&1
 RC=$?
 set -e
 
 test $RC -eq 2
 
-grep 'There are 2 nodes where the coastline is not closed.$' $LOG
+grep 'There are 2 nodes where the coastline is not closed.$' "$LOG"
 
-grep '^There were 0 warnings.$' $LOG
-grep '^There were 2 errors.$' $LOG
+grep '^There were 0 warnings.$' "$LOG"
+grep '^There were 2 errors.$' "$LOG"
 
 check_count land_polygons 0;
 check_count error_points 2;
 check_count error_lines 0;
 
-echo "SELECT AsText(geometry), osm_id, error FROM error_points;" | $SQL >$DUMP
+echo "SELECT InsertEpsgSrid(4326);" | $SQL
 
-grep -F 'POINT(1 1)|100|fixed_end_point' $DUMP
-grep -F 'POINT(1 1)|104|fixed_end_point' $DUMP
+echo "SELECT AsText(Transform(geometry, 4326)), osm_id, error FROM error_points;" | $SQL >"$DUMP"
+
+grep -F 'POINT(1 1)|100|fixed_end_point' "$DUMP"
+grep -F 'POINT(1 1)|104|fixed_end_point' "$DUMP"
 
 #-----------------------------------------------------------------------------
